starcluster.commands.listclusters

Package starcluster :: Package commands :: Module listclusters |
[hide private]
[frames] | no frames]

# Source Code for Module starcluster.commands.listclusters

     1  #!/usr/bin/env python
     2
     3  from completers import ClusterCompleter
     4
     5
     6 -class CmdListClusters(ClusterCompleter):
     7      """
     8      listclusters [<cluster_tag> ...]
     9
    10      List all active clusters
    11      """
    12      names = ['listclusters', 'lc']
    13
    14 -    def addopts(self, parser):
    15          parser.add_option("-s", "--show-ssh-status", dest="show_ssh_status",
    16                            action="store_true", default=False,
    17                            help="output whether SSH is up on each node or not")
    18
    19 -    def execute(self, args):
    20          self.cm.list_clusters(cluster_groups=args,
    21                                show_ssh_status=self.opts.show_ssh_status)
    22